@@ -4,7 +4,7 @@
  *	  utilities routines for the postgres inverted index access method.
  *
  *
- * Portions Copyright (c) 2015-2019, Postgres Professional
+ * Portions Copyright (c) 2015-2022, Postgres Professional
  * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -128,6 +128,9 @@ rumhandler(PG_FUNCTION_ARGS)
 	amroutine->ampredlocks = true;
 #if PG_VERSION_NUM >= 100000
 	amroutine->amcanparallel = false;
+#endif
+#if PG_VERSION_NUM >= 150000
+	amroutine->amhotblocking = true;
 #endif
 	amroutine->amkeytype = InvalidOid;
 
